sqlobject.tests.test_datetime module — SQLObject 3.9.1 documentation

# sqlobject.tests.test_datetime module

class `sqlobject.tests.test_datetime.` `DateTime1`(**kw)

  Bases: `sqlobject.main.SQLObject`

  property `col1`
  property `col2`
  property `col3`
  `j` = date_time1
  `q` = date_time1
  class `sqlmeta`(instance)

    Bases: `sqlobject.main.sqlmeta`

    `childName` = None
    `idName` = 'id'
    `indexes` = []
    `joinDefinitions` = []
    `joins` = []
    `soClass`

      alias of `sqlobject.tests.test_datetime.DateTime1`

    `style` = <sqlobject.styles.MixedCaseUnderscoreStyle object>
    `table` = 'date_time1'

`sqlobject.tests.test_datetime.` `test_dateTime`()

`sqlobject.tests.test_datetime.` `test_microseconds`()